Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NumgoArray ¶
NumgoArray represents a multidimensional array
func Array ¶
func Array(data []float64) *NumgoArray
Array creates a new NumgoArray from a slice of float64 values
func NewNumgoArray ¶
func NewNumgoArray(shape []int) *NumgoArray
NewNumgoArray creates a new NumgoArray with the given shape and initializes it with zeros
func NewNumgoArrayFromSlice ¶
func NewNumgoArrayFromSlice(data []float64, shape []int) *NumgoArray
NewNumgoArrayFromSlice creates a new NumgoArray from a slice of float64 values and the given shape
func (*NumgoArray) Get ¶
func (a *NumgoArray) Get(indices ...int) float64
Get returns the value of an element at the given indices
func (*NumgoArray) Set ¶
func (a *NumgoArray) Set(value float64, indices ...int)
Set sets the value of an element at the given indices
Click to show internal directories.
Click to hide internal directories.